]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - server.h
mmd: rename dbinfo to selector_info
[paraslash.git] / server.h
index fe6d858199c97a5a27ed586b76a6c8078840ad63..da777f771d90386e2626183b6ba120e4bde49514 100644 (file)
--- a/server.h
+++ b/server.h
@@ -21,7 +21,7 @@
 #include "para.h"
 
 
/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 
 /**
@@ -139,8 +139,8 @@ struct misc_meta_data{
        unsigned int active_connections;
 /** the process id of para_server */
        pid_t server_pid;
-/** a string that gets filled in by the current database tool */
-       char dbinfo[MMD_INFO_SIZE];
+/** a string that gets filled in by the current audio file selector */
+       char selector_info[MMD_INFO_SIZE];
 /** the number if the current database tool */
        int dbt_num;
 /** commands set this to non-zero to request a database tool change */
@@ -21,7 +21,7 @@
 
 
-/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
+/** size of the selector_info and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 